@@ -7,16 +7,16 @@
 #' @description
 #'  \Sexpr[results=rd, stage=render]{lifecycle::badge("experimental")}
 #'
-#'  Catches side effects (error, warnings, messages), strips the message strings of
+#'  Catches side effects (\code{error}, \code{warning}s, \code{message}s), strips the message strings of
 #'  non-alphanumeric characters with \code{\link[xpectr:strip]{strip()}} and regenerates them.
 #'
 #'  When numbers in error messages vary slightly between systems
 #'  (and this variation isn't important to catch), we can strip the numbers as well.
 #'
-#'  Use case: Sometimes testthat tests have differences in punctuation and newlines on different
+#'  Use case: Sometimes \code{testthat} tests have differences in punctuation and newlines on different
 #'  systems. By stripping both the error message and the expected message
 #'  (with \code{\link[xpectr:strip]{strip()}}), we can avoid such failed tests.
-#' @param x Code that potentially throws warnings, messages, or an error.
+#' @param x Code that potentially throws \code{warning}s, \code{message}s, or an \code{error}.
 #' @inheritParams strip
 #' @author Ludvig Renbo Olsen, \email{r-pkgs@@ludvigolsen.dk}
 #' @family strippers
@@ -27,7 +27,7 @@
 #' library(xpectr)
 #' library(testthat)
 #'
-#' \donttest{
+#' \dontrun{
 #' strip_msg(stop("this 'dot' .\n is removed! 123"))
 #' strip_msg(warning("this 'dot' .\n is removed! 123"))
 #' strip_msg(message("this 'dot' .\n is removed! 123"))
@@ -41,7 +41,8 @@
 #' expect_error(strip_msg(error_fn(), remove_numbers = TRUE),
 #'              strip("this 'dot' .\n is removed! 123", remove_numbers = TRUE))
 #' }
-strip_msg <- function(x, remove_spaces = FALSE, remove_numbers = FALSE){
+strip_msg <- function(x, remove_spaces = FALSE, remove_numbers = FALSE,
+                      remove_ansi = TRUE, lowercase = FALSE){
 
   # Catch x lexically
   # Needed with direct message() calls
@@ -50,7 +51,9 @@ strip_msg <- function(x, remove_spaces = FALSE, remove_numbers = FALSE){
   side_effects <- capture_side_effects(eval(x, envir = parent.frame(4)))
   stripper <- function(msg) {
     strip(msg, remove_spaces = remove_spaces,
-          remove_numbers = remove_numbers)
+          remove_numbers = remove_numbers,
+          remove_ansi = remove_ansi,
+          lowercase = lowercase)
   }
 
   # Regenerate error
